Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2950)

Unified Diff: blimp/net/engine_authentication_handler.h

Issue 2281783002: Changes client_token to be client_auth_token. (Closed)
Patch Set: Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: blimp/net/engine_authentication_handler.h
diff --git a/blimp/net/engine_authentication_handler.h b/blimp/net/engine_authentication_handler.h
index 89bbc500a7ffb38521e10fe8f4c8a61e8fd00e44..91d510a2c16456fbc683c46af003168414a07617 100644
--- a/blimp/net/engine_authentication_handler.h
+++ b/blimp/net/engine_authentication_handler.h
@@ -21,11 +21,11 @@ class BlimpMessage;
// to |connection_handler|.
class BLIMP_NET_EXPORT EngineAuthenticationHandler : public ConnectionHandler {
public:
// |client_token|: used to authenticate incoming connection.
// |connection_handler|: a new connection is passed on to it after the
// connection is authenticate this handler.
EngineAuthenticationHandler(ConnectionHandler* connection_handler,
- const std::string& client_token);
+ const std::string& client_auth_token);
~EngineAuthenticationHandler() override;
@@ -38,7 +38,7 @@ class BLIMP_NET_EXPORT EngineAuthenticationHandler : public ConnectionHandler {
// Used to authenticate incoming connection. Engine is assigned to one client
// only, and all connections from that client shall carry the same token.
- const std::string client_token_;
+ const std::string client_auth_token_;
DISALLOW_COPY_AND_ASSIGN(EngineAuthenticationHandler);
};
@@ -21,11 +21,11 @@ class BlimpMessage;
class BLIMP_NET_EXPORT EngineAuthenticationHandler : public ConnectionHandler {
public:
- // |client_token|: used to authenticate incoming connection.
+ // |client_auth_token|: used to authenticate incoming connection.
// |connection_handler|: a new connection is passed on to it after the
// connection is authenticate this handler.

Powered by Google App Engine
This is Rietveld 408576698